@@ -29,13 +29,12 @@
 #include <gtk/gtk.h>
 #include <canberra-gtk.h>
 
-#include "connect4.h"
+#include "ai.h"
 #include "main.h"
 #include "theme.h"
 #include "prefs.h"
 #include "gfx.h"
 #include "games-gridframe.h"
-#include "games-stock.h"
 
 #define SPEED_MOVE     25
 #define SPEED_DROP     20
@@ -100,6 +99,9 @@ static void process_move2 (gint c);
 static void process_move3 (gint c);
 
 
+
+
+
 static void
 clear_board (void)
 {
@@ -370,7 +372,6 @@ static void
 game_init (void)
 {
   g_random_set_seed ((guint) time (NULL));
-  vboard = veleng_init ();
 
   anim = ANIM_NONE;
   gameover = TRUE;
@@ -420,7 +421,7 @@ game_reset (void)
     } else {
       vstr[0] = vlevel[p.level[PLAYER2]];
     }
-    game_process_move (playgame (vstr, vboard) - 1);
+    game_process_move (playgame (vstr) - 1);
   }
 }
 
@@ -429,7 +430,6 @@ game_reset (void)
 static void
 game_free (void)
 {
-  veleng_free (vboard);
   gfx_free ();
 }
 
@@ -529,20 +529,24 @@ prompt_player (void)
     break;
   case 2:
   case 0:
-    if (player == PLAYER1)
-	who = _(theme_get_player (PLAYER1));
-    else
-	who = _(theme_get_player (PLAYER2));
 
     if (gameover) {
-	str = g_strdup_printf (_("%s wins!"), who);
+	if (player == PLAYER1)
+	  who = _(theme_get_player_win (PLAYER1));
+	else
+	  who = _(theme_get_player_win (PLAYER2));
+	str = g_strdup_printf (_("%s"), who);
       }
     else if (player_active) {
       set_status_message (_("Your Turn"));
       return;
 
     } else {
-      str = g_strdup_printf (_("%s’s Turn"), who);
+	if (player == PLAYER1)
+	  who = _(theme_get_player_turn (PLAYER1));
+	else
+	  who = _(theme_get_player_turn (PLAYER2));
+        str = g_strdup_printf (_("%s"), who);
     }
 
     set_status_message (str);
@@ -628,7 +632,7 @@ on_game_hint (GSimpleAction *action, GVariant *parameter, gpointer data)
   set_status_message (_("I’m Thinking…"));
 
   vstr[0] = vlevel[LEVEL_STRONG];
-  c = playgame (vstr, vboard) - 1;
+  c = playgame (vstr) - 1;
 
   column_moveto = c;
   while (timeout)
@@ -1073,7 +1077,7 @@ process_move3 (gint c)
       } else {
 	vstr[0] = vlevel[p.level[PLAYER2]];
       }
-      c = playgame (vstr, vboard) - 1;
+      c = playgame (vstr) - 1;
       if (c < 0)
 	gameover = TRUE;
       g_timeout_add (SPEED_DROP,
@@ -1307,7 +1311,7 @@ main (int argc, char *argv[])
     g_error_free (error);
     exit (1);
   }
-  
+
   settings = g_settings_new ("org.gnome.four-in-a-row");
 
   g_set_application_name (_(APPNAME_LONG));
